==> sqlite_dao_ext-0.1.6.tar.gz: sqlite_dao_ext-0.1.6/sqlite_dao_ext/sqlite_dao/sqlite_dao.py <==
from typing import Type, List, Generic, TypeVar, Dict, Any

from sqlite_dao_ext.sqlite_client.sqlite_client import SqliteClient
from sqlite_dao_ext.sqlite_client.sqlite_query import SqliteQuery
from sqlite_dao_ext.sqlite_dao.sqlite_data_object import SqliteDataObject
from sqlite_dao_ext.sqlite_dao.sqlite_query_generator import SqliteQueryGenerator

SDO = TypeVar("SDO", bound=SqliteDataObject)


class SqliteDao(Generic[SDO]):
    _sqlite_client: SqliteClient
    _data_type: Type[SDO]
    _sql_generator: SqliteQueryGenerator
    _table_name: str

    def __init__(self, sqlite_client: SqliteClient, data_type: Type[SqliteDataObject]):
        self._sqlite_client = sqlite_client
        self._data_type = data_type
        self._table_name = data_type.table_name()
        self._sql_generator = SqliteQueryGenerator(clz=self._data_type)
        self.create_table()

    def create_table(self):
        self._sqlite_client.execute(*self._sql_generator.create_table_sql)

    def drop_table(self):
        self._sqlite_client.execute(self._sql_generator.drop_table_sql)

    def insert(self, objs: List[SDO]):
        return self._sqlite_client.batch_insert(
            self._sql_generator.insert_sql(objs=objs)
        )

    def insert_or_replace(self, objs: List[SDO]):
        return self._sqlite_client.batch_insert(
            self._sql_generator.insert_sql(objs=objs, supplement="OR REPLACE")
        )

    def insert_or_ignore(self, objs: List[SDO]):
        return self._sqlite_client.batch_insert(
            self._sql_generator.insert_sql(objs=objs, supplement="OR IGNORE")
        )

    def delete_by_values(self, **value_map):
        return self._sqlite_client.execute(
            self._sql_generator.delete_by_values_sql(value_map),
        )

    def count_by_values(self, **value_map) -> int:
        return self.count_group_by_values([], **value_map)[0]["count"]

    def count_group_by_values(
        self, group_by: List[str], **value_map
    ) -> List[Dict[str, Any]]:
        return self._sqlite_client.execute(
            self._sql_generator.count_by_values_sql(value_map, group_by or []),
            commit=False,
        )[0]

    def query_by_values(
        self, limit: int = 100, offset: int = 0, **value_map
    ) -> List[SDO]:
        return list(
            map(
                self._data_type.loads,
                self._sqlite_client.execute(
                    self._sql_generator.query_by_values_sql(
                        value_map, limit=limit, offset=offset
                    ),
                    commit=False,
                )[0],
            )
        )

    def execute(self, *queries: SqliteQuery, commit: bool = True):
        return self._sqlite_client.execute(*queries, commit=commit)

    def __str__(self):
        return f"SqliteDao<{self._data_type.__name__}>(sqlite_client={self._sqlite_client})"

    def __repr__(self):
        return str(self)

==> sqlite_dao_ext-0.1.8.tar.gz: sqlite_dao_ext-0.1.8/sqlite_dao_ext/sqlite_dao/sqlite_dao.py <==
from typing import Type, List, Generic, TypeVar, Dict, Any

from sqlite_dao_ext.sqlite_client.sqlite_client import SqliteClient
from sqlite_dao_ext.sqlite_client.sqlite_query import SqliteQuery
from sqlite_dao_ext.sqlite_dao.sqlite_data_object import SqliteDataObject
from sqlite_dao_ext.sqlite_dao.sqlite_query_generator import SqliteQueryGenerator

SDO = TypeVar("SDO", bound=SqliteDataObject)


class SqliteDao(Generic[SDO]):
    _sqlite_client: SqliteClient
    _data_type: Type[SDO]
    _sql_generator: SqliteQueryGenerator
    _table_name: str

    def __init__(self, sqlite_client: SqliteClient, data_type: Type[SqliteDataObject]):
        self._sqlite_client = sqlite_client
        self._data_type = data_type
        self._table_name = data_type.table_name()
        self._sql_generator = SqliteQueryGenerator(clz=self._data_type)
        self.create_table()

    def create_table(self):
        self._sqlite_client.execute(*self._sql_generator.create_table_sql)

    def drop_table(self):
        self._sqlite_client.execute(self._sql_generator.drop_table_sql)

    def insert(self, objs: List[SDO]):
        return self._sqlite_client.batch_insert(
            self._sql_generator.insert_sql(objs=objs)
        )

    def insert_or_replace(self, objs: List[SDO]):
        return self._sqlite_client.batch_insert(
            self._sql_generator.insert_sql(objs=objs, supplement="OR REPLACE")
        )

    def insert_or_ignore(self, objs: List[SDO]):
        return self._sqlite_client.batch_insert(
            self._sql_generator.insert_sql(objs=objs, supplement="OR IGNORE")
        )

    def delete_by_values(self, **value_map):
        return self._sqlite_client.execute(
            self._sql_generator.delete_by_values_sql(value_map),
        )

    def count_by_values(self, **value_map) -> int:
        return self.count_group_by_values([], **value_map)[0]["count"]

    def count_group_by_values(
        self, group_by: List[str], **value_map
    ) -> List[Dict[str, Any]]:
        return self._sqlite_client.execute(
            self._sql_generator.count_by_values_sql(value_map, group_by or []),
            commit=False,
        )[0]

    def query_by_values(
        self, limit: int = 100, offset: int = 0, **value_map
    ) -> List[SDO]:
        return list(
            map(
                self._data_type.loads,
                self.query_fields_by_values([], limit, offset, **value_map),
            )
        )

    def query_fields_by_values(
        self, fields: List[str], limit: int = 100, offset: int = 0, **value_map
    ) -> List[Dict[str, Any]]:
        return self._sqlite_client.execute(
            self._sql_generator.query_by_values_sql(
                value_map, limit=limit, offset=offset, fields=fields or []
            ),
            commit=False,
        )[0]

    def execute(self, *queries: SqliteQuery, commit: bool = True):
        return self._sqlite_client.execute(*queries, commit=commit)

    def __str__(self):
        return f"SqliteDao<{self._data_type.__name__}>(sqlite_client={self._sqlite_client})"

    def __repr__(self):
        return str(self)
